<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

$config['mail_protocol'] = [
    'mail'     => 'mail',
    'sendmail' => 'sendmail',
    'smtp'     => 'smtp',
];

$config['mailtype'] = [
    1 => 'html',
    2 => 'text',
];

$config['priority'] = [
    1 => '1 (highest)',
    2 => '2',
    3 => '3 (normal, default)',
    4 => '4',
    5 => '5 (lowest)',
];

